@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -40,15 +40,16 @@ goffset  tracker_file_get_size                     (const gchar  *uri);
 guint64  tracker_file_get_mtime                    (const gchar  *uri);
 gchar *  tracker_file_get_mime_type                (GFile        *file);
 gboolean tracker_file_system_has_enough_space      (const gchar  *path,
-                                                    gulong        required_bytes);
-void     tracker_path_remove                       (const gchar  *uri);
+                                                    gulong        required_bytes,
+                                                    gboolean      creating_db);
 gboolean tracker_path_is_in_path                   (const gchar  *path,
                                                     const gchar  *in_path);
-void     tracker_path_hash_table_filter_duplicates (GHashTable   *roots);
 GSList * tracker_path_list_filter_duplicates       (GSList       *roots,
-                                                    const gchar  *basename_exception_prefix);
+                                                    const gchar  *basename_exception_prefix,
+                                                    gboolean      is_recursive);
 gchar *  tracker_path_evaluate_name                (const gchar  *uri);
 
+gboolean tracker_path_has_write_access_or_was_created (const gchar *path);
 gboolean tracker_env_check_xdg_dirs                (void);
 
 gboolean tracker_file_lock                         (GFile *file);
