@@ -1,7 +1,6 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2006, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -54,35 +53,32 @@
 #include "tracker-dbus.h"
 #include "tracker-extract.h"
 
-#define ABOUT								  \
+#define ABOUT	  \
 	"Tracker " PACKAGE_VERSION "\n"
 
-#define LICENSE								  \
+#define LICENSE	  \
 	"This program is free software and comes without any warranty.\n" \
-	"It is licensed under version 2 or later of the General Public "  \
-	"License which can be viewed at:\n"				  \
-	"\n"								  \
+	"It is licensed under version 2 or later of the General Public " \
+	"License which can be viewed at:\n" \
+	"\n" \
 	"  http://www.gnu.org/licenses/gpl.txt\n"
 
 #define QUIT_TIMEOUT 30 /* 1/2 minutes worth of seconds */
 
-static GMainLoop  *main_loop;
-static guint       quit_timeout_id = 0;
+static GMainLoop *main_loop;
+static guint quit_timeout_id = 0;
 
-static gboolean    version;
-static gint        verbosity = -1;
-static gchar      *filename;
-static gchar      *mime_type;
-static gboolean    disable_shutdown;
-static gboolean    force_internal_extractors;
+static gint verbosity = -1;
+static gchar *filename;
+static gchar *mime_type;
+static gboolean disable_shutdown;
+static gboolean force_internal_extractors;
+static gchar *force_module;
+static gboolean version;
 
 static TrackerFTSConfig *fts_config;
 
-static GOptionEntry  entries[] = {
-	{ "version", 'V', 0,
-	  G_OPTION_ARG_NONE, &version,
-	  N_("Displays version information"),
-	  NULL },
+static GOptionEntry entries[] = {
 	{ "verbosity", 'v', 0,
 	  G_OPTION_ARG_INT, &verbosity,
 	  N_("Logging, 0 = errors only, "
@@ -92,7 +88,7 @@ static GOptionEntry  entries[] = {
 	  G_OPTION_ARG_FILENAME, &filename,
 	  N_("File to extract metadata for"),
 	  N_("FILE") },
-	{ "mime", 'm', 0,
+	{ "mime", 't', 0,
 	  G_OPTION_ARG_STRING, &mime_type,
 	  N_("MIME type for file (if not provided, this will be guessed)"),
 	  N_("MIME") },
@@ -106,6 +102,14 @@ static GOptionEntry  entries[] = {
 	  G_OPTION_ARG_NONE, &force_internal_extractors,
 	  N_("Force internal extractors over 3rd parties like libstreamanalyzer"),
 	  NULL },
+	{ "force-module", 'm', 0,
+	  G_OPTION_ARG_STRING, &force_module,
+	  N_("Force a module to be used for extraction (e.g. \"foo\" for \"foo.so\")"),
+	  N_("MODULE") },
+	{ "version", 'V', 0,
+	  G_OPTION_ARG_NONE, &version,
+	  N_("Displays version information"),
+	  NULL },
 	{ NULL }
 };
 
@@ -113,7 +117,7 @@ static gboolean
 quit_timeout_cb (gpointer user_data)
 {
 	quit_timeout_id = 0;
-	
+
 	if (!disable_shutdown) {
 		g_main_loop_quit (main_loop);
 	} else {
@@ -130,9 +134,9 @@ tracker_main_quit_timeout_reset (void)
 		g_source_remove (quit_timeout_id);
 	}
 
-	quit_timeout_id = g_timeout_add_seconds (QUIT_TIMEOUT, 
-						 quit_timeout_cb, 
-						 NULL);
+	quit_timeout_id = g_timeout_add_seconds (QUIT_TIMEOUT,
+	                                         quit_timeout_cb,
+	                                         NULL);
 }
 
 static void
@@ -146,7 +150,7 @@ initialize_priority (void)
 	 * so complains if we do not check its returned value. But it
 	 * seems that since glibc 2.2.4, nice() can return -1 on a
 	 * successful call so we have to check value of errno too.
-	 * Stupid... 
+	 * Stupid...
 	 */
 	g_message ("Setting process priority");
 
@@ -154,7 +158,7 @@ initialize_priority (void)
 		const gchar *str = g_strerror (errno);
 
 		g_message ("Couldn't set nice value to 19, %s",
-			   str ? str : "no error given");
+		           str ? str : "no error given");
 	}
 }
 
@@ -166,11 +170,11 @@ initialize_directories (void)
 	/* NOTE: We don't create the database directories here, the
 	 * tracker-db-manager does that for us.
 	 */
-	
+
 	user_data_dir = g_build_filename (g_get_user_data_dir (),
-					  "tracker",
-					  NULL);
-	
+	                                  "tracker",
+	                                  NULL);
+
 	/* g_message ("Checking directory exists:'%s'", user_data_dir); */
 	g_mkdir_with_parents (user_data_dir, 00755);
 
@@ -197,12 +201,14 @@ signal_handler (int signo)
 		in_loop = TRUE;
 		disable_shutdown = FALSE;
 		quit_timeout_cb (NULL);
+
+		/* Fall through */
 	default:
 		if (g_strsignal (signo)) {
 			g_print ("\n");
 			g_print ("Received signal:%d->'%s'\n",
-				 signo,
-				 g_strsignal (signo));
+			         signo,
+			         g_strsignal (signo));
 		}
 		break;
 	}
@@ -213,7 +219,7 @@ initialize_signal_handler (void)
 {
 #ifndef G_OS_WIN32
 	struct sigaction act;
-	sigset_t	 empty_mask;
+	sigset_t         empty_mask;
 
 	sigemptyset (&empty_mask);
 	act.sa_handler = signal_handler;
@@ -230,9 +236,9 @@ initialize_signal_handler (void)
 
 static void
 log_handler (const gchar    *domain,
-	     GLogLevelFlags  log_level,
-	     const gchar    *message,
-	     gpointer	     user_data)
+             GLogLevelFlags  log_level,
+             const gchar    *message,
+             gpointer        user_data)
 {
 	if (!tracker_log_should_handle (log_level, verbosity)) {
 		return;
@@ -255,7 +261,7 @@ log_handler (const gchar    *domain,
 		g_fprintf (stdout, "%s\n", message);
 		fflush (stdout);
 		break;
-	}	
+	}
 }
 
 TrackerFTSConfig *
@@ -279,9 +285,9 @@ run_standalone (void)
 
 	/* Set log handler for library messages */
 	log_handler_id = g_log_set_handler (NULL,
-					    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL,
-					    log_handler,
-					    NULL);
+	                                    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL,
+	                                    log_handler,
+	                                    NULL);
 
 	g_log_set_default_handler (log_handler, NULL);
 
@@ -299,7 +305,8 @@ run_standalone (void)
 	uri = g_file_get_uri (file);
 
 	object = tracker_extract_new (disable_shutdown,
-				      force_internal_extractors);
+	                              force_internal_extractors,
+	                              force_module);
 
 	if (!object) {
 		g_free (uri);
@@ -323,22 +330,22 @@ run_standalone (void)
 
 	return EXIT_SUCCESS;
 }
- 
+
 int
 main (int argc, char *argv[])
 {
 	GOptionContext *context;
 	GError         *error = NULL;
 	TrackerConfig  *config;
-        TrackerExtract *object;
+	TrackerExtract *object;
 	gchar          *log_filename = NULL;
 
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	/* Translators: this message will appear immediately after the	*/
-	/* usage string - Usage: COMMAND [OPTION]... <THIS_MESSAGE>	*/
+	/* Translators: this message will appear immediately after the  */
+	/* usage string - Usage: COMMAND [OPTION]... <THIS_MESSAGE>     */
 	context = g_option_context_new (_("- Extract file meta data"));
 
 	g_option_context_add_main_entries (context, entries, NULL);
@@ -348,7 +355,21 @@ main (int argc, char *argv[])
 		gchar *help;
 
 		g_printerr ("%s\n\n",
-			    _("Filename and mime type must be provided together"));
+		            _("Filename and mime type must be provided together"));
+
+		help = g_option_context_get_help (context, TRUE, NULL);
+		g_option_context_free (context);
+		g_printerr ("%s", help);
+		g_free (help);
+
+		return EXIT_FAILURE;
+	}
+
+	if (force_internal_extractors && force_module) {
+		gchar *help;
+
+		g_printerr ("%s\n\n",
+		            _("Options --force-internal-extractors and --force-module can't be used together"));
 
 		help = g_option_context_get_help (context, TRUE, NULL);
 		g_option_context_free (context);
@@ -369,7 +390,7 @@ main (int argc, char *argv[])
 
 	if (!filename) {
 		g_print ("  Shutdown after 30 seconds of inactivitiy is %s\n",
-			 disable_shutdown ? "disabled" : "enabled");
+		         disable_shutdown ? "disabled" : "enabled");
 	}
 
 	initialize_signal_handler ();
@@ -389,7 +410,7 @@ main (int argc, char *argv[])
 	/* Set conditions when we use stand alone settings */
 	if (filename) {
 		return run_standalone ();
-	} 
+	}
 
 	/* Initialize subsystems */
 	initialize_directories ();
@@ -416,7 +437,8 @@ main (int argc, char *argv[])
 	}
 
 	object = tracker_extract_new (disable_shutdown,
-				      force_internal_extractors);
+	                              force_internal_extractors,
+	                              force_module);
 
 	if (!object) {
 		g_object_unref (config);
